#include <time.h>
#include "defs.h"

/* return filename corresponding to a number defined in defs.h/enums.h */
void text_file_number_to_char(gint number, gchar *filename, gint my_find)
{
    gchar buf[BUF_SIZE_SMALL];
    gchar *buf2;

    strcpy(filename, "");

    switch(number)
    {
	default:
	    strcpy(buf, "country_eng");
	    break;
	case TEXT_FILES_COUNTRY_DE:
	    strcpy(buf, "country_de");
	    break;
	case TEXT_FILES_COUNTRY_IT:
	    strcpy(buf, "country_it");
	    break;
	case TEXT_FILES_COUNTRY_FR:
	    strcpy(buf, "country_fr");
	    break;
	case TEXT_FILES_COUNTRY_ES:
	    strcpy(buf, "country_es");
	    break;
	case TEXT_FILES_COUNTRY_RO:
	    strcpy(buf, "country_ro");
	    break;
	case TEXT_FILES_COUNTRY_BR:
	    strcpy(buf, "country_br");
	    break;
	case TEXT_FILES_COUNTRY_PL:
	    strcpy(buf, "country_pl");
	    break;
	case TEXT_FILES_PLAYER_NAMES:
	    strcpy(buf, "player_names");
	    break;
	case TEXT_FILES_DEFINITIONS:
	    strcpy(buf, "teams");
	    break;
	case TEXT_FILES_HELP:
	  strcpy(buf, "help");
	    break;
    }

    buf2 = find_support_file(buf);

    if(my_find == 1 && buf2 != NULL)
    {
	strcpy(filename, buf2);
	g_free(buf2);
	return;
    }

    if(buf2 != NULL)
	g_free(buf2);

    strcpy(filename, buf);
}

/* try to make a .bygfoot directory in the user's home directory
   and copy the support files there if possible */
void check_home_dir(void)
{
    gint i, success = 1;
    gchar home[BUF_SIZE_SMALL];
    gchar buf[BUF_SIZE_SMALL];
    gchar buf2[BUF_SIZE_SMALL];
    gchar buf3[BUF_SIZE_SMALL];
    gchar text_files[TEXT_FILES_END][BUF_SIZE_SMALL];
    gchar text_files_full_path[TEXT_FILES_END][BUF_SIZE_SMALL];
    FILE *help_file;

    sprintf(home, "%s", getenv("HOME"));

    /* check help file version */
    sprintf(buf, "%s/.bygfoot/text_files", home);
    sprintf(buf2, "%s/help", buf);
    help_file = fopen(buf2, "r");
    if(help_file != NULL)
      {
	fscanf(help_file, "%[^\n]", buf3);
	fclose(help_file);
	if(strcmp(buf3, "Bygfoot Football Manager 1.4.2") != 0)
	  {
	    sprintf(buf3, "mv -vf %s %s/help.old", buf2, buf);
	    system(buf3);
	  }
      }

    for(i=0;i<TEXT_FILES_END;i++)
    {
	text_file_number_to_char(i, text_files_full_path[i], 1);
	text_file_number_to_char(i, text_files[i], 0);
    }

    sprintf(buf, "test -d %s/.bygfoot", home);
    if(system(buf) != 0)
    {
	g_print("\nCreating %s/.bygfoot. . .\n", home);
	sprintf(buf2, "mkdir -v %s/.bygfoot", home);
	
	if(system(buf2) == 0)
	    g_print("Done.\n");
	else
	    g_print("Failed. This isn't a serious problem if you don't want to edit teams.\nMaybe you should create the directory manually\nand copy all text files from the text_files directory.\n");
    }
	
    if(system(buf) != 0)
	return;
    
    sprintf(buf, "%s/.bygfoot", home);
    sprintf(buf2, "mkdir -v %s/.bygfoot/saves", home);
    sprintf(buf3, "test -d %s/saves", buf);
    if(system(buf3) != 0)
	system(buf2);

    sprintf(buf2, "mkdir -v %s/text_files", buf);
    sprintf(buf3, "test -d %s/text_files", buf);
    if(system(buf3) != 0)
	system(buf2);
    
    for(i=0;i<TEXT_FILES_END;i++)
    {
	sprintf(buf3, "test -e %s/text_files/%s", buf, text_files[i]);
	if(system(buf3) != 0)
	{
	    if(strcmp(text_files_full_path[i], "") != 0)
	    {
		g_print("Copying ");
		sprintf(buf3, "cp -v %s %s/text_files/%s", text_files_full_path[i], buf,
			text_files[i]);
	    }
	    if(system(buf3) != 0)
		success = 0;
	}
    }
    
    if(success == 0)
    {
	g_print("\nSome files could not be copied to %s.\nYou should try to copy them manually:\n\n", buf);
	for(i=0;i<TEXT_FILES_END;i++)
	{
	    sprintf(buf3, "test -e %s/text_files/%s", buf, text_files[i]);
	    if(system(buf3) != 0 && 
	       strcmp(text_files_full_path[i], "") != 0)
		g_print("%s\n", text_files_full_path[i]);
	}
    }
}

/* check for the files with team and player names
   and help file */
void check_files(void)
{
    gint i;
    gchar filenames[3][BUF_SIZE_SMALL];
    FILE *fil;
    
    text_file_number_to_char(TEXT_FILES_COUNTRY_ENG, filenames[0], 0);
    text_file_number_to_char(TEXT_FILES_PLAYER_NAMES, filenames[1], 0);
    text_file_number_to_char(TEXT_FILES_HELP, filenames[2], 0);
    for(i=0;i<3;i++)
    {
	fil = fopen(find_support_file(filenames[i]), "r");
	if(fil == NULL)
	{
	    g_print("\n*** Couldn't find file: %s ***\n\n", filenames[i]);
	    g_print("\n*** You can add the path to the support files by calling 'bygfoot -d my_support_files_path' ***\n\n");
	    if(i < 2)
		exit(5);
	}
	
	if(fil != NULL)
	    fclose(fil);
    }
}

/* check whether 'item' is in array 'list' between
   'min' and 'max' */
gint is_in_list(gint *list, gint min, gint max, gint item)
{
    gint i;

    for(i=min;i<=max;i++)
	if(item == list[i])
	    return 1;
    
    return 0;
}

/* check whether 'item' is in array 'list' between
   'min' and 'max'; this time we compare strings */
gint is_in_list_char(gchar list[][50], gint min,
		     gint max, gchar *item)
{
    gint i;
    
    for(i=min;i<=max;i++)
	if(!strcmp(item, list[i]))
	    return 1;
    
    return 0;
}

/* write team or player names from 'filename'
   to the array 'names'; both files are read until a '1000' appears
   in a line by itself */
void get_names(gchar *filename, gchar names[][50])
{
    gint i = 0;
    gint linenr = 0;
    gchar trash[BUF_SIZE_BIG];
    gchar buf[BUF_SIZE_SMALL];
    FILE *fil = fopen(filename, "r");
    
    while(1)
    {
	fscanf(fil,"%[^\n]", trash);
	linenr++;
	if(strcmp(trash, "1000") == 0 || feof(fil) != 0)
	{
	    fclose(fil);
	    break;
	}
	/* ignore comment lines */
	else if(trash[0] != '#')
	{
	    if(strlen(trash) < 50)
	    {
		strcpy(names[i], trash);
		i++;
	    }
	    else
	    {
		sprintf(buf,"*** The lines in '%s' which aren't comment lines (leading '#') must have length < 50. ***\nLine %d is too long! ***\n\n", filename, linenr);
		g_print("%s", buf);
	    }
	}

	fscanf(fil,"%[\n ]*", trash);
    }
}

/* swap two integers */
void swap_int(gint *first, gint *second)
{
    gint swap = *first;

    *first = *second;
    *second = swap;
}

/* swap two floats */
void swap_float(gfloat *first, gfloat *second)
{
    gfloat swap = *first;

    *first = *second;
    *second = swap;
}

/* swap two strings */
void swap_char(gchar **first, gchar **second)
{
    gchar swap[BUF_SIZE_BIG];
    
    strcpy(swap, *first);
    strcpy(*first, *second);
    strcpy(*second, swap);
}

/* round an integer */
gint round_integer(gint number, gint places)
{
    return (gint)rint( (gfloat)number / powf(10, places) ) *
	powf(10, places);
}

/* return the index 0 or 1 for the variables like
   stadium_facts[] or goals[] */
gint get_statistics_variable_index(fixture fix)
{
    if(fix.type < 6000)
	return 1;

    if(fix.type > 50000 &&
       fix.type % 10 == 5)
	return 1;
    
    return 0;
}

/* print a thousands-grouped output of 'number' into 'buf',
   like 2 234 345 instead of 2234345 */
void print_grouped_int(gint number, gchar *buf, gint append)
{
    gint i;
    gchar buf2[BUF_SIZE_SMALL];
    gint length = 0;
    gfloat copy = (gfloat)(abs(number));
    gint number2 = abs(number);

    if(append == 0)
      strcpy(buf, "");

    while(copy >= 1)
    {
	copy /= 10;
	length++;
    }

    if(length > 9)
    {
	sprintf(buf2, "%d", number);
	strcat(buf, buf2);
	return;
    }

    for(i = length; i > 0; i--)
    {
	sprintf(buf2, "%d", get_place(number2, i));
	strcat(buf, buf2);
	if(i % 3 == 1)
	    strcat(buf, " ");
    }

    if(number < 0)
    {
	sprintf(buf2, "- ");
	strcat(buf2, buf);
	sprintf(buf, "%s", buf2);
    }
    else if(number == 0)
	strcat(buf, "0");
}

/* allocate the memory needed
   for 'dest' and copy 'source' into it */
void print_string(gchar **dest, const gchar *source)
{                                       
    if(*dest != NULL)
	g_free(*dest);

    *dest=(gchar*)g_malloc(strlen(source) + 1);
    strcpy(*dest, source);
}

/* free the history pointers */
void free_history(void)
{
    season_stat *stat = history;
    season_stat *stat2;

    if(history == NULL)
	return;

    stat2 = stat->next;
    while(stat2 != NULL)
    {
	g_free(stat);
	stat = stat2;
	stat2 = stat->next;
    }
    
    g_free(stat);

    history = NULL;
}

/* get a float representation of someone's age
   based on his birth year and month written as 
   an integer, e.g. 196510 for 1965, Oct. */
gfloat get_age_from_birth(gint date)
{
    GDate *current_date = g_date_new();
    GDate *birth_date = g_date_new();

    g_date_set_time(current_date, time(NULL));
    g_date_set_dmy(birth_date, 15, get_place(date, 22),
		   get_place(date, 14));

    return (gfloat)g_date_days_between(birth_date, current_date) / 365.25;
}
